@@ -237,51 +237,4 @@ def export(db, filename, cellname=None, scale = 1e-9, layermapfile="default.laye
             # import cairosvg here to avoid unnecessary lib installation for non-gds options.
             import cairosvg
             cairosvg.svg2png(url=svg_filename, write_to=png_filename, scale=1.0)
-    #gdspy.LayoutViewer()
-
-'''
-#export functions
-def export_from_laygo(db, filename, cellname=None, scale = 1e-9, layermapfile="default.layermap",
-                      physical_unit=1e-9, logical_unit=0.001, pin_label_height=0.1,
-                      pin_annotate_layer=['text', 'drawing'], text_height=0.1,
-                      abstract_instances = False, abstract_instances_layer = ['prBoundary', 'drawing']):
-    """
-    Export specified laygo2 object(s) to a GDS file
-
-    Parameters
-    ----------
-    db : laygo.object.database.Library
-        a library object that designs to be exported.
-    filename : str
-        the name of the output file.
-    cellname : list or str or None.
-        the name of cells to be exported. If None, all cells in the libname are exported.
-    scale : float
-        the scaling factor that converts integer coordinates to actual ones (mostly 1e-6, to convert 1 to 1um).
-    layermapfile : str
-        the name of layermap file.
-    physical_unit : float, optional
-        GDS physical unit.
-    logical_unit : float, optional
-        GDS logical unit.
-    pin_label_height : float, optional
-        the height of pin label.
-    pin_annotate_layer : [str, str], optional
-        pin annotate layer name (used when pinname is different from netname).
-    text_height : float, optional
-        the height of text
-    """
-    raise Exception("GDS support is currently disabled. Will be reinvented by using gds-tk.")
-
-
-def export(db, filename, cellname=None, scale = 1e-9, layermapfile="default.layermap",
-           physical_unit=1e-9, logical_unit=0.001, pin_label_height=0.1,
-           pin_annotate_layer=['text', 'drawing'], text_height=0.1,
-           abstract_instances=False, abstract_instances_layer=['prBoundary', 'drawing']):
-    """See laygo2.interface.gds.export_from_laygo for details."""
-    export_from_laygo(db, filename, cellname, scale, layermapfile,
-                      physical_unit, logical_unit, pin_label_height,
-                      pin_annotate_layer, text_height,
-                      abstract_instances, abstract_instances_layer)
-'''
-
+    #gdspy.LayoutViewer()
\ No newline at end of file
